==> openshift-model-monitoring-6.7.2-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebhookConfigBuilder extends WebhookConfigFluentImpl<WebhookConfigBuilder> implements VisitableBuilder<WebhookConfig,WebhookConfigBuilder>{
  public WebhookConfigBuilder() {
    this(false);
  }
  public WebhookConfigBuilder(Boolean validationEnabled) {
    this(new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMaxAlerts(instance.getMaxAlerts());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withUrl(instance.getUrl());
      fluent.withUrlSecret(instance.getUrlSecret());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WebhookConfigBuilder(WebhookConfig instance) {
    this(instance,false);
  }
  public WebhookConfigBuilder(WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withHttpConfig(instance.getHttpConfig());
      this.withMaxAlerts(instance.getMaxAlerts());
      this.withSendResolved(instance.getSendResolved());
      this.withUrl(instance.getUrl());
      this.withUrlSecret(instance.getUrlSecret());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WebhookConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebhookConfig build() {
    WebhookConfig buildable = new WebhookConfig(fluent.getHttpConfig(),fluent.getMaxAlerts(),fluent.getSendResolved(),fluent.getUrl(),fluent.getUrlSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}

==> openshift-model-monitoring-6.8.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/WebhookConfigBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class WebhookConfigBuilder extends WebhookConfigFluent<WebhookConfigBuilder> implements VisitableBuilder<WebhookConfig,WebhookConfigBuilder>{
  public WebhookConfigBuilder() {
    this(false);
  }
  public WebhookConfigBuilder(Boolean validationEnabled) {
    this(new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent) {
    this(fluent, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new WebhookConfig(), validationEnabled);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance) {
    this(fluent, instance, false);
  }
  public WebhookConfigBuilder(WebhookConfigFluent<?> fluent,WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new WebhookConfig());

    if (instance != null) {
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMaxAlerts(instance.getMaxAlerts());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withUrl(instance.getUrl());
      fluent.withUrlSecret(instance.getUrlSecret());
      fluent.withHttpConfig(instance.getHttpConfig());
      fluent.withMaxAlerts(instance.getMaxAlerts());
      fluent.withSendResolved(instance.getSendResolved());
      fluent.withUrl(instance.getUrl());
      fluent.withUrlSecret(instance.getUrlSecret());
      fluent.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  public WebhookConfigBuilder(WebhookConfig instance) {
    this(instance,false);
  }
  public WebhookConfigBuilder(WebhookConfig instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new WebhookConfig());

    if (instance != null) {
      this.withHttpConfig(instance.getHttpConfig());
      this.withMaxAlerts(instance.getMaxAlerts());
      this.withSendResolved(instance.getSendResolved());
      this.withUrl(instance.getUrl());
      this.withUrlSecret(instance.getUrlSecret());
      this.withHttpConfig(instance.getHttpConfig());
      this.withMaxAlerts(instance.getMaxAlerts());
      this.withSendResolved(instance.getSendResolved());
      this.withUrl(instance.getUrl());
      this.withUrlSecret(instance.getUrlSecret());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
    this.validationEnabled = validationEnabled; 
  }
  WebhookConfigFluent<?> fluent;
  Boolean validationEnabled;
  public WebhookConfig build() {
    WebhookConfig buildable = new WebhookConfig(fluent.buildHttpConfig(),fluent.getMaxAlerts(),fluent.getSendResolved(),fluent.getUrl(),fluent.getUrlSecret());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
